@@ -15,8 +15,8 @@ class ShiftsQuerySet(BaseRefQuerySet):
 
 class ShiftsManager(BaseRefManager):
 
-    @staticmethod
-    def getRecord(record):
+    @classmethod
+    def getRecord(cls, record):
         res = {
             'id': record.id,
             'code': record.code,
