@@ -82,8 +82,10 @@ class Crypto_file(AuditModel):
     @classmethod
     def check_file(cls, attfile):
         attfile = make_REPLACE_FILE_PATH(str(attfile))
+        logger.debug(f'check_file: {attfile}')
 
         if attfile is None or attfile == '':
+            logger.debug(f'file: {attfile} not exists')
             return attfile, False
         else:
             filename = attfile
@@ -91,19 +93,19 @@ class Crypto_file(AuditModel):
             if isinstance(settings.FILES_STORE, str):
                 _, exists = cls.exists(filename)
                 if exists is False or getsize(filename) == 0:
+                    logger.debug(f'file: {attfile} not exists')
                     return filename, False
 
             elif isinstance(settings.FILES_STORE, dict) and settings.FILES_STORE.get('mode') == SFTP:
                 ssh_client = settings.SSH_CLIENTS.client(settings.FILES_STORE)
                 res = ssh_client.exists(filename)
-                if res is True:
-                    if ssh_client.getsize(filename) == 0:
-                        return filename, False
-                else:
-                    return filename, res
+                if res is False or ssh_client.getsize(filename) == 0:
+                    logger.debug(f'file: {attfile} not exists')
+                    return filename, False
             else:
                 raise Exception(FILES_STORE_UNKNOWN_TYPE)
 
+            logger.debug(f'file: {attfile} exists')
             return filename, True
 
     @classmethod
@@ -136,7 +138,7 @@ class Crypto_file(AuditModel):
     @classmethod
     def copy_file(cls, uploadItemEx):
 
-        if isinstance(settings.FILES_STORE, dict):
+        if isinstance(settings.OLD_FILES, dict):
             ssh_client = settings.SSH_CLIENTS.client(settings.OLD_FILES)
             if ssh_client.exists(uploadItemEx.real_file_name):
                 ssh_client.get(localpath=uploadItemEx.full_path, remotepath=uploadItemEx.real_file_name)
