@@ -1,7 +1,7 @@
 import logging
 from datetime import timedelta
 
-from django.db.models import Manager, CharField, DateTimeField, UniqueConstraint, Q, Model, BigAutoField
+from django.db.models import Manager, Model, CharField, DateTimeField, UniqueConstraint, Q, BigAutoField
 from django.utils import timezone
 
 from history import utils
