@@ -21,6 +21,6 @@ def makeInfo():
         info.append(dict(libName=libName, libVersion=libVersion))
 
     file = open('MakeAboutData.js', 'w')
-    str = f"simpleSyS.aboutData = {json.dumps(info)}"
-    file.write(str)
+    string = f"simpleSyS.aboutData = {json.dumps(info)}"
+    file.write(string)
     file.close()
