@@ -6,6 +6,7 @@ from isc_common import setAttr, delAttr, dictinct_list
 from isc_common.auth.managers.base_user_manager import BaseUserManager, BaseUserQuerySet
 from isc_common.auth.models.usergroup import UserGroup
 from isc_common.bit import IsBitOn
+from isc_common.common.functions import get_dict_only_model_field
 from isc_common.http.DSRequest import DSRequest
 
 logger = logging.getLogger(__name__)
@@ -119,6 +120,8 @@ class UserManager(BaseUserManager):
         return cls.getRecord(**record)
 
     def updateFromRequest(self, request):
+        from isc_common.auth.models.user import User
+
         request = DSRequest(request=request)
         data = request.get_data()
 
@@ -136,7 +139,6 @@ class UserManager(BaseUserManager):
 
         data = self._remove_prop_(data)
         values = [item for item in dictinct_list(set(_oldValues) - set(data)) if not item.startswith('_')]
-        # values = [item for item in list(set(_oldValues) - set(data)) if not item.startswith('_')]
         for item in values:
             setAttr(data, item, None)
 
@@ -144,51 +146,45 @@ class UserManager(BaseUserManager):
         if user_id is None:
             user_id = data.get('id')
 
-        delAttr(data, 'bot')
-        delAttr(data, 'grid')
-        delAttr(data, 'id')
-        delAttr(data, 'short_name')
-        delAttr(data, 'short_name1')
-        delAttr(data, 'status')
-        delAttr(data, 'timer')
-        delAttr(data, 'timer4Close')
-        delAttr(data, 'ws')
+        super().filter(id=user_id).update(**get_dict_only_model_field(data=data, model=User, exclude=['password']))
 
-        super().filter(id=user_id).update(**data)
-
-        if data.get('password', None) != _oldValues.get('password'):
-            user = self.model.objects.get(pk=user_id)
+        user = self.model.objects.get(id=user_id)
+        if user.check_password(data.get('password')) is False:
             user.set_password(data.get('password', None))
             user.save()
-            user = self.model.objects.get(pk=user_id)
             setAttr(data, 'password', user.password)
             setAttr(data, 'short_name', user.get_short_name)
 
         return _data
 
     def createFromRequest(self, request):
+        from isc_common.auth.models.user import User
+
         request = DSRequest(request=request)
         data = request.get_data(excluded_keys=['id'])
+
         usergroup_id = data.get('usergroup_id')
         delAttr(data, 'usergroup_id')
         delAttr(data, 'on_line')
-        user = super().create(**self.clone_data(data))
-        password = request.get_data(excluded_keys=['id']).get('password', None)
-        user = self.model.objects.get(pk=user.id)
+
+        kwarg = self.clone_data(data=data, model=User)
+        user = User.objects.create(**kwarg)
+        password = request.get_data(excluded_keys=['id']).get('password')
+
         user.set_password(password)
         user.save(using=self._db)
-        user = self.model.objects.get(pk=user.id)
+
+        user = User.objects.get(pk=user.id)
         if isinstance(usergroup_id, list):
             for group in usergroup_id:
                 user.usergroup.add(group)
+
         res = model_to_dict(user)
         setAttr(res, 'props', res.get('props')._value)
-        return self.clone_data(res)
+
+        return res
 
     def _create_user(self, usergroup, username, email, password, **extra_fields):
-        """
-        Create and save a user with the given username, email, and password.
-        """
         if not username:
             raise ValueError('The given username must be set')
 
