@@ -2,11 +2,11 @@ import logging
 
 from bitfield import BitField
 
+from isc_common.auth.models.user import User
 from isc_common.fields.code_field import CodeStrictField
 from isc_common.fields.related import ForeignKeyProtect
 from isc_common.models.audit import AuditModel, AuditManager
 from isc_common.models.e_mails import E_mails, Model_e_mailQuerySet
-from lfl_admin.user_ext.models.persons import User
 
 logger = logging.getLogger(__name__)
 
