@@ -18,6 +18,7 @@ deleted = "deleted"
 developers = "developers"
 doing = "doing"
 execution = "execution"
+FILES_STORE_UNKNOWN_TYPE = "FILES_STORE неизвестного типа"
 formirovanie = "formirovanie"
 gray = "#808080"
 green = "green"
@@ -29,25 +30,31 @@ made = "made"
 new = "new"
 new_man = "new_man"
 not_relevant = "not_relevant"
+notDefined = "Не определен"
 orange = "orange"
 otkryt = "otkryt"
 otmenen = "otmenen"
 red = "red"
-notDefined = "Не определен"
+tournaments_offset = 10000000
+DELETE_ONE_STAGE = 'DELETE_ONE_STAGE'
+delete_image_refs = 'delete_image_refs'
 restarted = "restarted"
 route_made = "route_made"
 route_made_error = "route_made_error"
+SFTP = "SFTP"
+shirts = "shirts"
 sht = "шт"
 started = "started"
-shirts = "shirts"
 started_another = "started_another"
 stoped = "stoped"
 transferred = "transferred"
-unknown = "unknown"
 undefined = "undefined"
+unknown = "unknown"
+unknown_name = 'Не задан'
 update = "update"
 value_odd = "value_odd"
 zakryt = "zakryt"
+ONE_STAGE_ADDING = 'ONE_STAGE_ADDING'
 
 name_closed = "Закрыт"
 name_doing = "Выполнен"
