@@ -1,6 +1,6 @@
 import logging
 
-from isc_common import setAttr, delAttr, Wrapper
+from isc_common import setAttr, delAttr, Wrapper, delAttr1
 from isc_common.http.RPCRequest import RPCRequest
 from isc_common.json import BytesToJson
 
@@ -8,7 +8,7 @@ logger = logging.getLogger(__name__)
 
 
 class RequestData:
-    def __init__(self, _dict=None, request=None):
+    def __init__(self, _dict = None, request = None):
         if request:
             self.__data_dict__ = request.get_data()
         elif _dict:
@@ -17,7 +17,7 @@ class RequestData:
             self.__data_dict__ = dict()
         super()
 
-    def getDataOfKey(self, key, default=None):
+    def getDataOfKey(self, key, default = None):
         return self.__data_dict__.get(key, default)
 
     def update(self, key, value):
@@ -62,7 +62,7 @@ class DSRequest(RPCRequest):
         from isc_common.auth.models.user import User
         if self._user is None:
             if self.httpHeaders is not None and self.httpHeaders.USER_ID:
-                self._user = User.objects.get(id=self.httpHeaders.USER_ID)
+                self._user = User.objects.get(id = self.httpHeaders.USER_ID)
                 return self._user
             else:
                 if self.transaction is not None:
@@ -71,7 +71,7 @@ class DSRequest(RPCRequest):
                         for operation in operations:
                             data = operation.data
                             if data.httpHeaders is not None and data.httpHeaders.USER_ID is not None:
-                                self._user = User.objects.get(id=data.httpHeaders.USER_ID)
+                                self._user = User.objects.get(id = data.httpHeaders.USER_ID)
                                 return self._user
 
                 # raise Exception('user not enable type')
@@ -103,15 +103,14 @@ class DSRequest(RPCRequest):
 
         _user = ToInt(user)
         if isinstance(_user, int):
-            self._user = User.objects.get(id=_user)
+            self._user = User.objects.get(id = _user)
         elif isinstance(user, str):
-            self._user = User.objects.get(username=user)
+            self._user = User.objects.get(username = user)
         else:
             raise Exception('user not enable type')
 
-    def __init__(self, request):
-        from django.http import QueryDict
-        if request is not None and request.body != b'':
+    def __init__(self, request, **kwargs):
+        if request is not None and request.method == "POST" and request.body != b'':
             self.json = BytesToJson(request.body)
             if isinstance(self.json, dict) and len(self.json) > 0:
                 data = self.json.get('data')
@@ -129,26 +128,31 @@ class DSRequest(RPCRequest):
                             self.host = httpHeaders.get('HOST')
 
                         if httpHeaders.get('USERNAME') is not None:
-                            self.set_user_data(user=httpHeaders.get('USERNAME'))
+                            self.set_user_data(user = httpHeaders.get('USERNAME'))
 
                         if httpHeaders.get('USER_ID') is not None:
-                            self.set_user_data(user=httpHeaders.get('USER_ID'))
+                            self.set_user_data(user = httpHeaders.get('USER_ID'))
 
                         delAttr(self.json.get('data'), 'httpHeaders')
                     else:
                         if data.get('user_id') is not None:
-                            self.set_user_data(user=data.get('user_id'))
+                            self.set_user_data(user = data.get('user_id'))
                 else:
                     login = self.json.get('login')
                     if login is not None:
-                        self.set_user_data(user=login)
+                        self.set_user_data(user = login)
                     else:
                         httpHeaders = self.json.get('httpHeaders')
                         if httpHeaders is not None:
-                            self.set_user_data(user=httpHeaders.get('USER_ID'))
+                            self.set_user_data(user = httpHeaders.get('USER_ID'))
 
-        elif isinstance(request.GET, QueryDict):
+        elif request.method == "GET":
             get_dict = dict(request.GET)
+            self.json = get_dict
+
+            if not self.json:
+                self.json = delAttr1(kwargs, "asnc")
+
             ws_channel = get_dict.get('ws_channel')
             if isinstance(ws_channel, list) and len(ws_channel) > 0:
                 self.ws_channel = ws_channel[0]
@@ -163,7 +167,7 @@ class DSRequest(RPCRequest):
 
             user_id = get_dict.get('user_id')
             if isinstance(user_id, list) and len(user_id) > 0:
-                self.set_user_data(user=user_id[0])
+                self.set_user_data(user = user_id[0])
 
         RPCRequest.__init__(self, self.json)
 
@@ -177,7 +181,7 @@ class DSRequest(RPCRequest):
                 setAttr(res, key, value)
         return res
 
-    def get_data(self, excluded_keys=['grid']):
+    def get_data(self, excluded_keys = ['grid']):
         res = None
         if isinstance(self.json, dict):
             data = self.json.get('data')
@@ -193,10 +197,10 @@ class DSRequest(RPCRequest):
         # return self.delete_underscore_element(res)
         return res
 
-    def get_data_wrapped(self, excluded_keys=['grid'], cls=Wrapper):
-        return cls(**self.get_data(excluded_keys=excluded_keys))
+    def get_data_wrapped(self, excluded_keys = ['grid'], cls = Wrapper):
+        return cls(**self.get_data(excluded_keys = excluded_keys))
 
-    def get_old_data(self, excluded_keys=['grid']):
+    def get_old_data(self, excluded_keys = ['grid']):
         res = None
         if isinstance(self.json, dict):
             data = self.json.get('oldValues')
@@ -211,10 +215,10 @@ class DSRequest(RPCRequest):
         # return self.delete_underscore_element(res)
         return res
 
-    def get_old_data_wrapped(self, excluded_keys=['grid'], cls=Wrapper):
-        return cls(**self.get_old_data(excluded_keys=excluded_keys))
+    def get_old_data_wrapped(self, excluded_keys = ['grid'], cls = Wrapper):
+        return cls(**self.get_old_data(excluded_keys = excluded_keys))
 
-    def get_all_data(self, excluded_keys=['grid']):
+    def get_all_data(self, excluded_keys = ['grid']):
         res = None
         if isinstance(self.json, dict):
             data = self.json.get('data')
@@ -243,15 +247,15 @@ class DSRequest(RPCRequest):
 
         setAttr(self.json, 'sortBy', sort_by)
 
-    def set_criteria(self, criteria, excluded_keys=['grid']):
-        data = self.get_all_data(excluded_keys=excluded_keys)
+    def set_criteria(self, criteria, excluded_keys = ['grid']):
+        data = self.get_all_data(excluded_keys = excluded_keys)
         if isinstance(data, dict):
             setAttr(data, 'criteria', criteria)
         else:
             delAttr(data, 'criteria')
 
-    def get_criteria(self, excluded_keys=['grid']):
-        data = self.get_data(excluded_keys=excluded_keys)
+    def get_criteria(self, excluded_keys = ['grid']):
+        data = self.get_data(excluded_keys = excluded_keys)
         if isinstance(data, dict):
             criteria = data.get('criteria')
         else:
@@ -262,7 +266,7 @@ class DSRequest(RPCRequest):
         else:
             return []
 
-    def get_data_array(self, excluded_keys=['grid']):
+    def get_data_array(self, excluded_keys = ['grid']):
         res = None
         if isinstance(self.json, dict):
             transaction = self.json.get('transaction')
@@ -275,7 +279,7 @@ class DSRequest(RPCRequest):
             # res = (True, [dict((key, value) for (key, value) in operation.items() if value is not None and not str(key).startswith('_') and key not in excluded_keys) for operation in operations])
         return res
 
-    def get_oldValues(self, excluded_keys=['grid']):
+    def get_oldValues(self, excluded_keys = ['grid']):
         res = None
         if isinstance(self.json, dict):
             if self.json.get('oldValues', None) and isinstance(self.json.get('oldValues', None), dict):
@@ -296,7 +300,7 @@ class DSRequest(RPCRequest):
     def get_username(self):
         return self.get_data().get('username')
 
-    def get_ids(self, field_name='id'):
+    def get_ids(self, field_name = 'id'):
         multi, data_array = self.get_data_array()
         if data_array:
             if multi:
@@ -307,7 +311,7 @@ class DSRequest(RPCRequest):
             ids = [0]
         return [id for id in ids if id is not None]
 
-    def get_tuple_ids(self, field_name='id'):
+    def get_tuple_ids(self, field_name = 'id'):
         multi, data_array = self.get_data_array()
         if data_array:
             if multi:
@@ -318,7 +322,7 @@ class DSRequest(RPCRequest):
             ids = [(0, "none")]
         return ids
 
-    def get_olds_tuple_ids(self, field_name='id'):
+    def get_olds_tuple_ids(self, field_name = 'id'):
         multi, data_array = self.get_data_array()
         if data_array:
             if multi:
@@ -329,7 +333,7 @@ class DSRequest(RPCRequest):
             ids = [(0, "none")]
         return ids
 
-    def get_old_ids(self, field_name='id'):
+    def get_old_ids(self, field_name = 'id'):
         multi, data_array = self.get_data_array()
         if data_array:
             if multi:
