@@ -65,12 +65,16 @@ class Body:
         elif self.body.httpHeaders is not None and self.body.httpHeaders.USER_ID:
             return User.objects.get(id=self.body.httpHeaders.USER_ID).username
         else:
-            if self.session is not None and self.session._session is not None:
+            if self.session is not None and hasattr(self.session, '_session_cache') and self.session._session is not None:
                 ws_channel = self.session._session.get('ws_channel')
                 if ws_channel is not None:
                     return ws_channel.split('_')[1]
                 else:
                     return user_name_anonim
+            elif self.session is None:
+                return user_name_anonim
+            elif hasattr(self.session, '_session_cache') is False or self.session._session is None:
+                return user_name_anonim
 
     @property
     def user(self):
@@ -185,6 +189,7 @@ def JsonWSResponseWithException(printing=False, printing_res=False):
                 return JsonResponse(DSResponseOk().response)
 
         return wrapper
+
     return JsonWSResponseWithExceptionInner
 
 
