@@ -1,6 +1,7 @@
 import logging
 from typing import List
 
+from asgiref.sync import sync_to_async
 from bitfield import Bit, BitHandler
 from django.core.exceptions import EmptyResultSet
 from django.db import connection, transaction
@@ -29,7 +30,7 @@ class ExtQuerySet(QuerySet):
 
 class ExtManager(Manager):
     def get_queryset(self):
-        return ExtQuerySet(self.model, using=self._db)
+        return ExtQuerySet(self.model, using = self._db)
 
     def getOptional(self, *args, **kwargs):
         try:
@@ -39,7 +40,7 @@ class ExtManager(Manager):
             return None
 
 
-def lazy_bulk_fetch(max_obj, max_count, fetch_func, start=0):
+def lazy_bulk_fetch(max_obj, max_count, fetch_func, start = 0):
     counter = start
     while counter < max_count:
         yield fetch_func()[counter:counter + max_obj]
@@ -49,7 +50,7 @@ def lazy_bulk_fetch(max_obj, max_count, fetch_func, start=0):
 class CommonQuerySet(QuerySet):
 
     def soft_restore(self):
-        res = super().update(deleted_at=None)
+        res = super().update(deleted_at = None)
         return res
 
     def hard_delete(self):
@@ -57,15 +58,15 @@ class CommonQuerySet(QuerySet):
         return res
 
     def alive(self):
-        return self.filter(deleted_at=None)
+        return self.filter(deleted_at = None)
 
     def dead(self):
-        return self.exclude(deleted_at=None)
+        return self.exclude(deleted_at = None)
 
-    def __init__(self, model=None, query=None, using=None, hints=None, alive_only=True, enabledAll=False):
+    def __init__(self, model = None, query = None, using = None, hints = None, alive_only = True, enabledAll = False):
         self.alive_only = alive_only
         self.enabledAll = enabledAll
-        super().__init__(model=model, query=query, using=using, hints=hints)
+        super().__init__(model = model, query = query, using = using, hints = hints)
 
     def get_field(self, field_name):
         fld = [x for x in self.model._meta.fields if x.name == field_name]
@@ -356,12 +357,12 @@ class CommonQuerySet(QuerySet):
                 setAttr(res, key, value)
         return res
 
-    def get_criteria(self, json=dict()):
+    def get_criteria(self, json = dict()):
 
         if json is None:
             data = dict()
         else:
-            data = json.get('data', dict())
+            data = json.get('data', json if isinstance(json, dict) else dict())
         _data = dict()
         if data is not None:
             for key, value in data.items():
@@ -402,7 +403,7 @@ class CommonQuerySet(QuerySet):
             # "exactCase"	case-sensitive exact match ("foo" matches only "foo")                       exact
             # "substring"	case-insenstive substring match ("foo" matches "foobar" and "BarFoo")       icontains
             # "startsWith"	case-insensitive prefix match ("foo" matches "FooBar" but not "BarFoo")     istartswith
-            textMatchStyle = self.textMatchStyleMapping(json.get('textMatchStyle'))
+            textMatchStyle = self.textMatchStyleMapping(json.get('textMatchStyle')) if isinstance(json, dict) else None
             for key, value in data.items():
                 if isinstance(value, Bit):
                     criteria.add(Q(**{f"{key}": value}), operator)
@@ -420,18 +421,7 @@ class CommonQuerySet(QuerySet):
                         criteria.add(Q(**{f"{key}__{textMatchStyle}": value}), operator)
         return criteria
 
-    def _get_range_rows(self, *args, **kwargs):
-        json = kwargs.get('json')
-        distinct_field_names = kwargs.get('distinct_field_names')
-        end = kwargs.get('end')
-        start = kwargs.get('start')
-
-        criteria = self.get_criteria(json=json)
-        # print(f'json: {json}')
-        # print(f'self.alive_only: {self.alive_only}')
-
-        ob = json.get("sortBy", [])
-
+    def get_query(self, distinct_field_names, start, end, criteria, args, ob):
         if isinstance(distinct_field_names, tuple) or (isinstance(distinct_field_names, list)):
             if self.alive_only == False:
                 if start is not None and end is not None:
@@ -444,13 +434,13 @@ class CommonQuerySet(QuerySet):
                     queryResult = super().filter(*args, criteria).distinct(*distinct_field_names)
             else:
                 if start is not None and end is not None:
-                    queryResult = super().filter(*args, criteria).filter(deleted_at__isnull=True).distinct(*distinct_field_names)[start:end]
+                    queryResult = super().filter(*args, criteria).filter(deleted_at__isnull = True).distinct(*distinct_field_names)[start:end]
                 elif start is not None and end is None:
-                    queryResult = super().filter(*args, criteria).filter(deleted_at__isnull=True).distinct(*distinct_field_names)[start:]
+                    queryResult = super().filter(*args, criteria).filter(deleted_at__isnull = True).distinct(*distinct_field_names)[start:]
                 elif end is not None and start is None:
-                    queryResult = super().filter(*args, criteria).filter(deleted_at__isnull=True).distinct(*distinct_field_names)[:end]
+                    queryResult = super().filter(*args, criteria).filter(deleted_at__isnull = True).distinct(*distinct_field_names)[:end]
                 else:
-                    queryResult = super().filter(*args, criteria).filter(deleted_at__isnull=True).distinct(*distinct_field_names)
+                    queryResult = super().filter(*args, criteria).filter(deleted_at__isnull = True).distinct(*distinct_field_names)
         else:
             if self.alive_only == False:
                 if start is not None and end is not None:
@@ -463,17 +453,39 @@ class CommonQuerySet(QuerySet):
                     queryResult = super().order_by(*ob).filter(*args, criteria)
             else:
                 if start is not None and end is not None:
-                    queryResult = super().order_by(*ob).filter(*args, criteria).filter(deleted_at__isnull=True)[start:end]
+                    queryResult = super().order_by(*ob).filter(*args, criteria).filter(deleted_at__isnull = True)[start:end]
                 elif start is not None and end is None:
-                    queryResult = super().order_by(*ob).filter(*args, criteria).filter(deleted_at__isnull=True)[start:]
+                    queryResult = super().order_by(*ob).filter(*args, criteria).filter(deleted_at__isnull = True)[start:]
                 elif end is not None and start is None:
-                    queryResult = super().order_by(*ob).filter(*args, criteria).filter(deleted_at__isnull=True)[:end]
+                    queryResult = super().order_by(*ob).filter(*args, criteria).filter(deleted_at__isnull = True)[:end]
                 else:
-                    queryResult = super().order_by(*ob).filter(*args, criteria).filter(deleted_at__isnull=True)
+                    queryResult = super().order_by(*ob).filter(*args, criteria).filter(deleted_at__isnull = True)
         return queryResult
 
-    def get_range_rows(self, start=None, end=None, function=None, json=None, distinct_field_names=None, user=None, *args, **kwargs):
-        queryResult = self._get_range_rows(*args, start=start, end=end, function=function, json=json, distinct_field_names=distinct_field_names)
+    def _get_range_rows(self, *args, **kwargs):
+        json = kwargs.get('json')
+
+        distinct_field_names = kwargs.get('distinct_field_names')
+        end = kwargs.get('end')
+        start = kwargs.get('start')
+
+        criteria = self.get_criteria(json = json)
+        # print(f'json: {json}')
+        # print(f'self.alive_only: {self.alive_only}')
+
+        ob = json.get("sortBy", []) if isinstance(json, dict) else []
+
+        return self.get_query(
+            distinct_field_names = distinct_field_names,
+            start = start,
+            end = end,
+            criteria = criteria,
+            args = args,
+            ob = ob
+        )
+
+    def get_range_rows(self, start = None, end = None, function = None, json = None, distinct_field_names = None, user = None, *args, **kwargs):
+        queryResult = self._get_range_rows(*args, start = start, end = end, function = function, json = json, distinct_field_names = distinct_field_names, **kwargs)
 
         try:
             logger.debug(f'\n\n{queryResult.query}\n')
@@ -487,8 +499,8 @@ class CommonQuerySet(QuerySet):
             res = [model_to_dict(record) for record in queryResult]
             return res
 
-    def get_range_rows1(self, request, function=None, distinct_field_names=None, remove_fields=None):
-        request = DSRequest(request=request)
+    def get_range_rows1(self, request, function = None, distinct_field_names = None, remove_fields = None, **kwargs):
+        request = DSRequest(request = request, **kwargs)
         if isinstance(remove_fields, list):
             data = request.json.get('data')
             deleted = False
@@ -501,13 +513,14 @@ class CommonQuerySet(QuerySet):
         self.alive_only = request.alive_only
         self.enabledAll = request.enabledAll
         res = self.get_range_rows(
-            start=request.startRow,
-            end=request.endRow,
-            function=function,
-            distinct_field_names=distinct_field_names,
-            json=request.json,
-            criteria=request.get_criteria(),
-            user=request.user
+            start = request.startRow,
+            end = request.endRow,
+            function = function,
+            distinct_field_names = distinct_field_names,
+            json = request.json,
+            criteria = request.get_criteria(),
+            user = request.user,
+            **kwargs
         )
         return res
 
@@ -526,14 +539,14 @@ class CommonQuerySet(QuerySet):
             logger.warning(ex)
 
         if function:
-            res = [function(record=record, user_id=user_id, ws_channel=ws_channel, ws_port=ws_port, host=host, username=username) for record in queryResult]
+            res = [function(record = record, user_id = user_id, ws_channel = ws_channel, ws_port = ws_port, host = host, username = username) for record in queryResult]
             return res
         else:
             res = [model_to_dict(record) for record in queryResult]
             return res
 
-    def get_range_rows3(self, start=None, end=None, function=None, json=None, distinct_field_names=None, user=None, *args, **kwargs):
-        queryResult = self._get_range_rows(*args, start=start, end=end, function=function, json=json, distinct_field_names=distinct_field_names)
+    def get_range_rows3(self, start = None, end = None, function = None, json = None, distinct_field_names = None, user = None, *args, **kwargs):
+        queryResult = self._get_range_rows(*args, start = start, end = end, function = function, json = json, distinct_field_names = distinct_field_names)
 
         logger.debug(f'\n\n{queryResult.query}\n')
         if function:
@@ -547,29 +560,29 @@ class CommonQuerySet(QuerySet):
         distinct_field_names = kwargs.get('distinct_field_names')
         function = kwargs.get('function')
 
-        request = DSRequest(request=request)
+        request = DSRequest(request = request)
         self.alive_only = request.alive_only
         self.enabledAll = request.enabledAll
         return self.get_range_rows2(
-            start=request.startRow,
-            end=request.endRow,
-            function=function,
-            distinct_field_names=distinct_field_names,
-            json=request.json,
-            username=request.username,
-            user_id=request.user_id,
-            ws_channel=request.ws_channel,
-            ws_port=request.ws_port,
-            host=request.host,
+            start = request.startRow,
+            end = request.endRow,
+            function = function,
+            distinct_field_names = distinct_field_names,
+            json = request.json,
+            username = request.username,
+            user_id = request.user_id,
+            ws_channel = request.ws_channel,
+            ws_port = request.ws_port,
+            host = request.host,
         )
 
     def get_info(self, request, *args):
-        request = DSRequest(request=request)
+        request = DSRequest(request = request)
         delAttr(request.json.get('data'), 'full_name')
-        criteria = self.get_criteria(json=request.json)
+        criteria = self.get_criteria(json = request.json)
         cnt = super().filter(*args, criteria).count()
         cnt_all = super().filter().count()
-        return dict(qty_rows=cnt, all_rows=cnt_all)
+        return dict(qty_rows = cnt, all_rows = cnt_all)
 
 
 class CommonManager(Manager):
@@ -600,7 +613,7 @@ class CommonManager(Manager):
             cursor.execute(f'REFRESH MATERIALIZED VIEW CONCURRENTLY {mat_view};')
             logger.debug(f'Refreshed')
 
-    def get_field(self, field_name, model=None):
+    def get_field(self, field_name, model = None):
         if not model:
             model = self.model
 
@@ -627,7 +640,7 @@ class CommonManager(Manager):
                     else:
                         fld = [x for x in model._meta.fields if x.name == _list_foreign]
                         if len(fld) == 1 and isinstance(fld[0], ForeignKeyProtect):
-                            fld = self.get_field(spliter.join(list_foreign[1:]), model=fld[0].related_model)
+                            fld = self.get_field(spliter.join(list_foreign[1:]), model = fld[0].related_model)
                         else:
                             break
         else:
@@ -638,13 +651,13 @@ class CommonManager(Manager):
         return None
 
     def get_queryset(self):
-        return CommonQuerySet(self.model, using=self._db)
+        return CommonQuerySet(self.model, using = self._db)
 
-    def get_range_rows1(self, request, function=None, distinct_field_names=None):
-        request = DSRequest(request=request)
+    def get_range_rows1(self, request, function = None, distinct_field_names = None):
+        request = DSRequest(request = request)
         self.alive_only = request.alive_only
         self.enabledAll = request.enabledAll
-        return self.get_queryset().get_range_rows(start=request.startRow, end=request.endRow, function=function, distinct_field_names=distinct_field_names, json=request.json)
+        return self.get_queryset().get_range_rows(start = request.startRow, end = request.endRow, function = function, distinct_field_names = distinct_field_names, json = request.json)
 
     def get_one_stage(self, data):
         if data.get('type') != ONE_STAGE_ADDING:
@@ -663,15 +676,15 @@ class CommonManager(Manager):
     @classmethod
     def getRecord(cls, record):
         return dict(
-            id=record.id
+            id = record.id
         )
 
     def getRec(self, id, model):
 
         if model is None:
-            res = self.getRecord(record=super().get(id=id))
+            res = self.getRecord(record = super().get(id = id))
         else:
-            res = self.getRecord(record=model.objects.get(id=id))
+            res = self.getRecord(record = model.objects.get(id = id))
         return res
 
     def _dataIsArray(self, data):
@@ -691,15 +704,15 @@ class CommonManager(Manager):
                     setAttr(res, key, data.get(key))
         return res
 
-    def clone_data(self, data, model=None):
+    def clone_data(self, data, model = None):
         _data = dict()
         if isinstance(data, dict):
             for key, val in data.items():
-                if self.get_field(field_name=key, model=model):
+                if self.get_field(field_name = key, model = model):
                     setAttr(_data, key, val)
         return _data
 
-    def get_prp(self, data, propsArr, props_name='props'):
+    def get_prp(self, data, propsArr, props_name = 'props'):
         if isinstance(data, dict):
             props = data.get(props_name, 0)
             if isinstance(propsArr, list):
@@ -719,7 +732,7 @@ class CommonManager(Manager):
                 return None
         return None
 
-    def get_expand_prp(self, data, propsArr, props_name='props'):
+    def get_expand_prp(self, data, propsArr, props_name = 'props'):
         if isinstance(data, dict):
             props = data.get(props_name, 0)
             if isinstance(propsArr, list):
@@ -753,14 +766,14 @@ class CommonManager(Manager):
                 setAttr(_data, k, TryToInt(v))
         return _data
 
-    def _createFromRequest(self, request, removed=None, propsArr: List = None):
+    def _createFromRequest(self, request, removed = None, propsArr: List = None):
 
-        request = DSRequest(request=request)
+        request = DSRequest(request = request)
         data = request.get_data()
 
-        one_stage_record = self.get_one_stage(data=data)
+        one_stage_record = self.get_one_stage(data = data)
         if one_stage_record is not None:
-            self.get_expand_prp(data=one_stage_record, propsArr=propsArr)
+            self.get_expand_prp(data = one_stage_record, propsArr = propsArr)
             return one_stage_record
 
         _data = data.copy()
@@ -772,27 +785,27 @@ class CommonManager(Manager):
 
         self._remove_prop(_data, removed)
 
-        props = self.get_prp(data=data, propsArr=propsArr)
+        props = self.get_prp(data = data, propsArr = propsArr)
         if props is not None:
             setAttr(_data, 'props', props)
 
-        record = get_dict_only_model_field(data=_data, model=self.model, exclude=['id'])
+        record = get_dict_only_model_field(data = _data, model = self.model, exclude = ['id'])
         res = super().create(**record)
 
         return res
 
-    def createFromRequest(self, request, model=None, removed=None, propsArr: List = None):
-        res = self._createFromRequest(request=request, removed=removed, propsArr=propsArr)
-        res = self.getRec(id=res.id, model=model)
+    def createFromRequest(self, request, model = None, removed = None, propsArr: List = None):
+        res = self._createFromRequest(request = request, removed = removed, propsArr = propsArr)
+        res = self.getRec(id = res.id, model = model)
         return res
 
-    def _updateFromRequest(self, request, removed=None, function=None, propsArr: List = None):
-        _request = DSRequest(request=request)
+    def _updateFromRequest(self, request, removed = None, function = None, propsArr: List = None):
+        _request = DSRequest(request = request)
         data = _request.get_data()
         if data is None:
-            data = self.get_data_from_GET(request=request)
+            data = self.get_data_from_GET(request = request)
 
-        data = self.check_data_for_multi_select(data=data)
+        data = self.check_data_for_multi_select(data = data)
 
         _data = data.copy()
         setAttr(_data, 'editor', request.user)
@@ -807,15 +820,15 @@ class CommonManager(Manager):
                     if function:
                         function(data, data_item)
                     else:
-                        props = self.get_prp(data=data_item, propsArr=propsArr)
+                        props = self.get_prp(data = data_item, propsArr = propsArr)
                         cloned_data = self.clone_data(data)
                         if props is not None:
                             setAttr(cloned_data, 'props', props)
 
                         if data_item.get('id'):
                             res, _ = super().update_or_create(
-                                id=data_item.get('id'),
-                                defaults=get_dict_only_model_field(data=cloned_data, model=self.model, exclude=['id'])
+                                id = data_item.get('id'),
+                                defaults = get_dict_only_model_field(data = cloned_data, model = self.model, exclude = ['id'])
                             )
                         else:
                             res = super().create(**cloned_data)
@@ -827,7 +840,7 @@ class CommonManager(Manager):
             if function:
                 res = function(data)
             else:
-                props = self.get_prp(data=data, propsArr=propsArr)
+                props = self.get_prp(data = data, propsArr = propsArr)
                 cloned_data = self.clone_data(data)
 
                 if props is not None:
@@ -841,27 +854,27 @@ class CommonManager(Manager):
                         delAttr(cloned_data, 'parent')
                         setAttr(cloned_data, 'parent_id', parent)
 
-                    record = get_dict_only_model_field(data=cloned_data, model=self.model, exclude=['id'])
-                    res = super().filter(id=_id).update(**record)
-                    res = super().get(id=_id)
+                    record = get_dict_only_model_field(data = cloned_data, model = self.model, exclude = ['id'])
+                    res = super().filter(id = _id).update(**record)
+                    res = super().get(id = _id)
                     # print(f'res: {res}')
                 else:
                     res = super().create(**cloned_data)
             return res
 
-    def updateFromRequest(self, request, model=None, removed=None, function=None, propsArr: List = None):
-        res = self._updateFromRequest(request=request, removed=removed, function=function, propsArr=propsArr)
+    def updateFromRequest(self, request, model = None, removed = None, function = None, propsArr: List = None):
+        res = self._updateFromRequest(request = request, removed = removed, function = function, propsArr = propsArr)
         if isinstance(res, list):
-            res = list(map(lambda id: self.getRec(id=id, model=model), res))
+            res = list(map(lambda id: self.getRec(id = id, model = model), res))
             return res
         else:
-            res = self.getRec(id=res.id if isinstance(res, Model) else res.get('id'), model=model)
+            res = self.getRec(id = res.id if isinstance(res, Model) else res.get('id'), model = model)
             return res
 
     def copyFromRequest(self, request):
-        request = DSRequest(request=request)
+        request = DSRequest(request = request)
         data = request.get_data()
-        old = self.get(id=data.get('id'))
+        old = self.get(id = data.get('id'))
         _old = model_to_dict(old)
         delAttr(_old, 'id')
         _old1 = dict()
@@ -882,7 +895,7 @@ class CommonManager(Manager):
                     value = _old.get(field_name)
                     if isinstance(value, str):
                         value = f'{_old.get(field_name)}-{num}'
-                        eval(f'self.get({field_name}="{value}")', dict(self=self))
+                        eval(f'self.get({field_name}="{value}")', dict(self = self))
                     else:
                         break
                     num += 1
@@ -911,7 +924,7 @@ class CommonManager(Manager):
                             get_str += f'{unique_together_item}="{value}",'
                             setAttr(get_dict, unique_together_item, value)
 
-                    eval(f'self.get({get_str})', dict(self=self))
+                    eval(f'self.get({get_str})', dict(self = self))
                     num += 1
                 except old.DoesNotExist:
                     for key, val in get_dict.items():
@@ -937,7 +950,7 @@ class CommonManager(Manager):
         return _old
 
     def lookupFromRequest(self, request):
-        request = DSRequest(request=request)
+        request = DSRequest(request = request)
         data = request.get_data()
 
         _data = dict()
@@ -1024,19 +1037,19 @@ class CommonManager(Manager):
         data = request.get_data()
         if data.get('mode') == DELETE_ONE_STAGE:
             id = data.get('id')
-            return super().filter(id=id).delete()
+            return super().filter(id = id).delete()
         return None
 
-    def deleteFromRequest(self, request, removed=None, model=None):
-        request = DSRequest(request=request)
+    def deleteFromRequest(self, request, removed = None, model = None):
+        request = DSRequest(request = request)
         tuple_ids = request.get_olds_tuple_ids()
         with transaction.atomic():
 
-            res = self.delete_image_refs(request=request)
+            res = self.delete_image_refs(request = request)
             if res is not None:
                 return res
 
-            res = self.delete_one_staage(request=request)
+            res = self.delete_one_staage(request = request)
             if res is not None:
                 return res
             res = 0
@@ -1044,21 +1057,21 @@ class CommonManager(Manager):
             for id, mode in tuple_ids:
                 if model is not None and issubclass(model, Model):
                     if mode == 'hide':
-                        model.objects.filter(id=id).soft_delete()
+                        model.objects.filter(id = id).soft_delete()
                         res += 1
                     elif mode == 'visible':
-                        model.objects.filter(id=id).soft_restore()
+                        model.objects.filter(id = id).soft_restore()
                     else:
-                        qty, _ = model.objects.filter(id=id).delete()
+                        qty, _ = model.objects.filter(id = id).delete()
                         res += qty
                 else:
                     if mode == 'hide':
-                        super().filter(id=id).soft_delete()
+                        super().filter(id = id).soft_delete()
                         res += 1
                     elif mode == 'visible':
-                        super().filter(id=id).soft_restore()
+                        super().filter(id = id).soft_restore()
                     else:
-                        qty, _ = super().filter(id=id).delete()
+                        qty, _ = super().filter(id = id).delete()
                         res += qty
         return res
 
