@@ -1,11 +1,11 @@
 import logging
 import os
+import shutil
 from datetime import datetime
 from urllib.parse import urljoin
 
 from django.conf import settings
-from django.core.files import File, locks
-from django.core.files.move import file_move_safe
+from django.core.files import File
 from django.core.files.storage import Storage
 from django.core.signals import setting_changed
 from django.utils import timezone
@@ -13,15 +13,14 @@ from django.utils._os import safe_join
 from django.utils.deconstruct import deconstructible
 from django.utils.encoding import filepath_to_uri
 from django.utils.functional import cached_property
+from isc_common.common import SFTP, FILES_STORE_UNKNOWN_TYPE
+from isc_common.oss.functions import get_tmp_dir
 
 logger = logging.getLogger(__name__)
 
 
 @deconstructible
 class CryptoFileSystemStorage(Storage):
-    """
-    Standard filesystem storage
-    """
 
     def __init__(self, location=None, base_url=None, file_permissions_mode=None, directory_permissions_mode=None):
         self._location = location
@@ -43,11 +42,18 @@ class CryptoFileSystemStorage(Storage):
             self.__dict__.pop('directory_permissions_mode', None)
 
     def _value_or_setting(self, value, setting):
-        return setting if value == None else value
+        return setting if value is None else value
 
     @cached_property
     def base_location(self):
-        return self._value_or_setting(self._location, settings.FILES_STORE)
+        if isinstance(settings.FILES_STORE, str):
+            file_store = settings.FILES_STORE
+        elif isinstance(settings.FILES_STORE, dict) and settings.FILES_STORE.get('mode') == SFTP:
+            file_store = get_tmp_dir()
+        else:
+            raise Exception(FILES_STORE_UNKNOWN_TYPE)
+
+        return self._value_or_setting(self._location, file_store)
 
     @cached_property
     def location(self):
@@ -55,7 +61,7 @@ class CryptoFileSystemStorage(Storage):
 
     @cached_property
     def base_url(self):
-        if self._base_url != None and not self._base_url.endswith('/'):
+        if self._base_url is not None and not self._base_url.endswith('/'):
             self._base_url += '/'
         return self._value_or_setting(self._base_url, settings.MEDIA_URL)
 
@@ -73,62 +79,32 @@ class CryptoFileSystemStorage(Storage):
     def _save(self, name, content):
         full_path = self.path(name)
 
-        directory = os.path.dirname(full_path)
-        if not os.path.exists(directory):
-            try:
-                if self.directory_permissions_mode != None:
-                    # os.makedirs applies the global umask, so we reset it,
-                    # for consistency with file_permissions_mode behavior.
-                    old_umask = os.umask(0)
-                    try:
-                        os.makedirs(directory, self.directory_permissions_mode)
-                    finally:
-                        os.umask(old_umask)
-                else:
-                    os.makedirs(directory)
-            except FileExistsError:
-                pass
-        if not os.path.isdir(directory):
-            raise IOError("%s exists and is not a directory." % directory)
+        if isinstance(settings.FILES_STORE, str):
+            _dir, _filename = os.path.split(full_path)
+            _filename1, _ = _filename.split('_')
 
-        while True:
-            try:
-                # This file has a file path that we can move.
-                if hasattr(content, 'temporary_file_path'):
-                    file_move_safe(content.temporary_file_path(), full_path)
+            name = f'{os.path.abspath(settings.FILES_STORE)}{os.sep}{_filename}'
 
-                # This is a normal uploadedfile that we can stream.
-                else:
-                    # This fun binary flag incantation makes os.open throw an
-                    # OSError if the file already exists before we open it.
-                    flags = (os.O_WRONLY | os.O_CREAT | os.O_EXCL |
-                             getattr(os, 'O_BINARY', 0))
-                    # The current umask value is masked out by os.open!
-                    fd = os.open(full_path, flags, 0o666)
-                    _file = None
-                    try:
-                        locks.lock(fd, locks.LOCK_EX)
-                        for chunk in content.chunks():
-                            if _file == None:
-                                mode = 'wb' if isinstance(chunk, bytes) else 'wt'
-                                _file = os.fdopen(fd, mode)
-                            _file.write(chunk)
-                    finally:
-                        locks.unlock(fd)
-                        if _file != None:
-                            _file.close()
-                        else:
-                            os.close(fd)
-            except FileExistsError:
-                # A new name is needed if the file exists.
-                name = self.get_available_name(name)
-                full_path = self.path(name)
-            else:
-                # OK, the file save worked. Break out of the loop.
-                break
+            shutil.copy2(src=f'{_dir}{os.sep}{_filename1}', dst=name)
 
-        if self.file_permissions_mode != None:
-            os.chmod(full_path, self.file_permissions_mode)
+            if self.file_permissions_mode is not None:
+                os.chmod(name, self.file_permissions_mode)
+
+        elif isinstance(settings.FILES_STORE, dict) and settings.FILES_STORE.get('mode') == SFTP:
+            _dir, _filename = os.path.split(full_path)
+            _filename1, _ = _filename.split('_')
+            name = f'{settings.FILES_STORE.get("PATH")}{os.sep}{_filename}'
+            localpath = f'{_dir}{os.sep}{_filename1}'
+
+            ssh_client = settings.SSH_CLIENTS.client(settings.FILES_STORE)
+            res = ssh_client.put(localpath=localpath, remotepath=name)
+            if res is not None:
+                raise res
+
+            if self.file_permissions_mode is not None:
+                ssh_client.chmod(path=name, mode=self.file_permissions_mode)
+        else:
+            raise Exception(FILES_STORE_UNKNOWN_TYPE)
 
         # Store filenames with forward slashes, even on Windows.
         return name.replace('\\', '/')
@@ -146,7 +122,6 @@ class CryptoFileSystemStorage(Storage):
             raise e
             # logger.warning(f'{name}: not found.')
 
-
     def exists(self, name):
         return os.path.exists(self.path(name))
 
@@ -167,18 +142,14 @@ class CryptoFileSystemStorage(Storage):
         return os.path.getsize(self.path(name))
 
     def url(self, name):
-        if self.base_url == None:
+        if self.base_url is None:
             raise ValueError("This file is not accessible via a URL.")
         url = filepath_to_uri(name)
-        if url != None:
+        if url is not None:
             url = url.lstrip('/')
         return urljoin(self.base_url, url)
 
     def _datetime_from_timestamp(self, ts):
-        """
-        If timezone support is enabled, make an aware datetime object in UTC;
-        otherwise make a naive one in the local timezone.
-        """
         if settings.USE_TZ:
             # Safe to use .replace() because UTC doesn't have DST
             return datetime.utcfromtimestamp(ts).replace(tzinfo=timezone.utc)
