@@ -59,6 +59,9 @@ class TypeScriptGenerator(AbstractGenerator):
             if not os.path.exists(dir):
                 os.mkdir(dir)
 
+            if os.path.exists(pathes_file):
+                os.remove(pathes_file)
+
             with open(pathes_file, 'w') as f:
                 for line in data_4_file:
                     f.write(line.replace('&amp;', '&'))
@@ -76,7 +79,7 @@ class TypeScriptGenerator(AbstractGenerator):
         if text is None:
             return None
 
-        return f'// {self._get_text(text)}'
+        return f'//{self._get_text(text)}'
 
     def _set_file_text(self, data_4_file: list, fragment_param):
         if not isinstance(data_4_file, list):
