@@ -17,8 +17,8 @@ class Messages_whomQuerySet(AuditQuerySet):
 
 class Messages_whomManager(AuditManager):
 
-    @staticmethod
-    def getRecord(record):
+    @classmethod
+    def getRecord(cls, record ) :
         res = {}
         return res
 
